@@ -23,6 +23,7 @@ from tencentcloud.cme.v20191029 import models
 class CmeClient(AbstractClient):
     _apiVersion = '2019-10-29'
     _endpoint = 'cme.tencentcloudapi.com'
+    _service = 'cme'
 
 
     def AddTeamMember(self, request):
@@ -112,7 +113,7 @@ class CmeClient(AbstractClient):
 
 
     def CreateProject(self, request):
-        """创建云剪的编辑项目，支持创建视频剪辑、直播剪辑及导播台项目。
+        """创建云剪的编辑项目，支持创建视频剪辑、直播剪辑、导播台项目以及视频拆条项目。
 
         :param request: Request instance for CreateProject.
         :type request: :class:`tencentcloud.cme.v20191029.models.CreateProjectRequest`
